[jboss-cvs] JBossAS SVN: r105937 - projects/cluster/ha-server-api/branches/1.2.x/src/main/java/org/jboss/ha/framework/server.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Thu Jun 10 16:14:43 EDT 2010


Author: bstansberry at jboss.com
Date: 2010-06-10 16:14:41 -0400 (Thu, 10 Jun 2010)
New Revision: 105937

Modified:
   projects/cluster/ha-server-api/branches/1.2.x/src/main/java/org/jboss/ha/framework/server/HATarget.java
Log:
[JBCLUSTER-282] Introduce a forward-compatible getReplicants() API

Modified: projects/cluster/ha-server-api/branches/1.2.x/src/main/java/org/jboss/ha/framework/server/HATarget.java
===================================================================
--- projects/cluster/ha-server-api/branches/1.2.x/src/main/java/org/jboss/ha/framework/server/HATarget.java	2010-06-10 19:57:00 UTC (rev 105936)
+++ projects/cluster/ha-server-api/branches/1.2.x/src/main/java/org/jboss/ha/framework/server/HATarget.java	2010-06-10 20:14:41 UTC (rev 105937)
@@ -33,12 +33,14 @@
 /** 
  * Control point representing a clustered service. Works with the 
  * {@link DistributedReplicantManager} to makes available a
  * {@link #getReplicants() list of replicants} (objects used to identify remote 
  * service endpoints around the cluster) for the service. Guards access to the 
  * service via the {@link #invocationsAllowed()} and 
  * {@link #setInvocationsAuthorization(int)} methods.
  *
  * @author bill at burkecentral.com
+ * @author Brian Stansberry
+ * 
  * @version $Revision$
  *
  * <p><b>Revisions:</b><br>
@@ -81,7 +83,7 @@
     * 
     * @param partition the {@link HAPartition} for the service's cluster
     * @param replicantName the name of the service
-    * @param target        the service's {@link #getReplicants() replicant}
+    * @param target        the service's {@link #getReplicantList() replicant}
     * @param allowInvocations <code>true</code> if {@link #invocationsAllowed()}
     *                         should return <code>true</code> immediately;
     *                         <code>false</code> if not
@@ -177,11 +179,26 @@
     * remote service endpoint for the service on a particular cluster node.
     * Examples include an RMI stub, a JBoss Remoting <code>InvokerLocator</code>
     * or an HTTP URL.
+    * 
+    * @deprecated use {@link #getReplicantList()}
     */
+   @Deprecated
    public ArrayList getReplicants()
    {
       return replicants;
    }
+   
+   /**
+    * Gets the replicants for the clustered service. A <code>replicant</code>
+    * is a service-specific object, typically something that represents a
+    * remote service endpoint for the service on a particular cluster node.
+    * Examples include an RMI stub, a JBoss Remoting <code>InvokerLocator</code>
+    * or an HTTP URL.
+    */
+   public List<?> getReplicantList()
+   {
+      return replicants;
+   }
 
    /**
     * Sets the behavior expected from {@link #invocationsAllowed()}. 
@@ -33,12 +33,14 @@
  * Control point representing a clustered service. Works with the 
  * {@link DistributedReplicantManager} to makes available a
- * {@link #getReplicants() list of replicants} (objects used to identify remote 
+ * {@link #getReplicantList() list of replicants} (objects used to identify remote 
  * service endpoints around the cluster) for the service. Guards access to the 
  * service via the {@link #invocationsAllowed()} and 



More information about the jboss-cvs-commits mailing list